DecodedTextRecord class

The decoded contents of a Text record: the text itself plus its language code (e.g. "en").

Constructors

DecodedTextRecord({required String text, required String languageCode})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
languageCode String
The language code from the record header.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The decoded text.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited